@@ -20,6 +20,8 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+#include <unistd.h>
+#include <string.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <signal.h>
@@ -175,6 +177,7 @@ netinfo_error_message (Netinfo     * netinfo,
 					 primary);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 						  secondary ? secondary : " ");
+	gtk_window_set_title (GTK_WINDOW (dialog), "");
 
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
 
